@@ -6,7 +6,10 @@ def getGlobalParameters(curbout, fps, pixelSize):
 
   BoutDuration = (curbout["BoutEnd"] - curbout["BoutStart"] + 1) / fps
   
-  NumberOfOscillations = len(curbout["Bend_Timing"]) / 2
+  if "Bend_Timing" in curbout and type(curbout["Bend_Timing"]) == list:
+    NumberOfOscillations = len(curbout["Bend_Timing"]) / 2
+  else:
+    NumberOfOscillations = float('NaN')
   
   TotalDistance = 0 
   posX = curbout["HeadX"]
@@ -21,10 +24,19 @@ def getGlobalParameters(curbout, fps, pixelSize):
   
   meanTBF = NumberOfOscillations / BoutDuration
   
-  maxAmplitude = max([abs(ta) for ta in curbout["TailAngle_smoothed"]])
+  if "TailAngle_smoothed" in curbout and len(curbout["TailAngle_smoothed"]):
+    maxAmplitude = max([abs(ta) for ta in curbout["TailAngle_smoothed"]])
+  else:
+    maxAmplitude = float('NaN')
   
-  firstBendTime = curbout["Bend_Timing"][0]
+  if "Bend_Timing" in curbout and type(curbout["Bend_Timing"]) == list:
+    firstBendTime = curbout["Bend_Timing"][0]
+  else:
+    firstBendTime = float('NaN')
   
-  firstBendAmplitude = abs(curbout["Bend_Amplitude"][0])
+  if "Bend_Amplitude" in curbout and type(curbout["Bend_Amplitude"]) == list:
+    firstBendAmplitude = abs(curbout["Bend_Amplitude"][0])
+  else:
+    firstBendAmplitude = float('NaN')
   
   return [BoutDuration, TotalDistance, Speed, NumberOfOscillations, meanTBF, maxAmplitude, posY[0], posY[len(posY)-1], np.mean(posY), firstBendTime, firstBendAmplitude]
